@@ -37,7 +37,7 @@ use POSIX qw(strftime);
 
 use URL::Encode qw(url_decode_utf8);
 
-our $VERSION = '2.1.4';  ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.1.5';  ## no critic (RequireInterpolationOfMetachars)
 
 __PACKAGE__->follow_best_practice;
 
@@ -445,12 +445,12 @@ sub serialize {
 
     string => sub {
 
-      if ($data) {
-        $data = ref $data ? $data->{content} : $data;
+      if ( defined $data ) {
+        $data = ref $data && defined $data->{content} ? $data->{content} : $data;
       }
 
       return $data
-        if $data;
+        if defined $data;
 
       return $exists ? $EMPTY : $data;
     },
@@ -458,7 +458,7 @@ sub serialize {
     boolean => sub {
 
       if ( ref $data ) {
-        if ( !blessed $data) {
+        if ( !blessed $data ) {
           $data = $data->{content};
         }
       }
